import { geoAlbersUsa, geoAlbers, geoPath, geoGraticule } from 'd3';
import { useMemo } from 'react';

//const projection = geoAlbers();
const projection = geoAlbersUsa();
const pathProj = geoPath(projection);
const graticule = geoGraticule();

export const MapMarks = ({
  data,
  atlas: { land, interiors },
  colorScale,
  colorValue,
  tooltipValue,
  tooltipFormat,
  onClick,
  selectedValue,
  onHover,
  hoveredValue,
  hoverOpacity,
  fadeOpacity
}) => (
  <g className="marks">
    {useMemo(
      () => (
        <>
          <path className="sphere" d={pathProj({ type: 'Sphere' })} />
          <path className="graticules" d={pathProj(graticule())} />
          <path className="interiors" d={pathProj(interiors)} />
        </>
      ),
      [pathProj, graticule, interiors]
    )}
    {useMemo(
      () =>
        land.features.map(feature => {
          const yId = feature.properties.name;
          //console.log('featureName:', yId);
          const stateColor = obj => {
            return data
              .filter(d => d.State === obj.properties.name)
              .map(d => colorScale(colorValue(d)));
          };
          return (
            <path
              className="land-state"
              d={pathProj(feature)}
              fill={stateColor(feature)}
              onClick={() => {
          console.log('clicked:', yId);
                onClick(yId);
              }}
              onMouseEnter={() => {
          console.log('hovered:', yId);
                onHover(yId);
              }}
              onMouseOut={() => {
                onHover(null);
              }}
              opacity={
                yId === selectedValue || yId === hoveredValue
                  ? hoverOpacity
                  : fadeOpacity
              }
              >
          <title>{yId}</title>
            </path>
          );
        }),
      [pathProj, land, data]
    )}
  </g>
);
